proto

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 18, 2026 License: AGPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	LLMService_Name_FullMethodName     = "/console.plugin.v1.LLMService/Name"
	LLMService_Complete_FullMethodName = "/console.plugin.v1.LLMService/Complete"
)
const (
	NotifierService_Name_FullMethodName   = "/console.plugin.v1.NotifierService/Name"
	NotifierService_Notify_FullMethodName = "/console.plugin.v1.NotifierService/Notify"
)
const (
	StatusProviderService_Name_FullMethodName  = "/console.plugin.v1.StatusProviderService/Name"
	StatusProviderService_Check_FullMethodName = "/console.plugin.v1.StatusProviderService/Check"
)
const (
	StoreService_CreateFlag_FullMethodName      = "/console.plugin.v1.StoreService/CreateFlag"
	StoreService_GetFlag_FullMethodName         = "/console.plugin.v1.StoreService/GetFlag"
	StoreService_ListFlags_FullMethodName       = "/console.plugin.v1.StoreService/ListFlags"
	StoreService_UpdateFlag_FullMethodName      = "/console.plugin.v1.StoreService/UpdateFlag"
	StoreService_DeleteFlag_FullMethodName      = "/console.plugin.v1.StoreService/DeleteFlag"
	StoreService_CreateComponent_FullMethodName = "/console.plugin.v1.StoreService/CreateComponent"
	StoreService_GetComponent_FullMethodName    = "/console.plugin.v1.StoreService/GetComponent"
	StoreService_ListComponents_FullMethodName  = "/console.plugin.v1.StoreService/ListComponents"
	StoreService_UpdateComponent_FullMethodName = "/console.plugin.v1.StoreService/UpdateComponent"
	StoreService_DeleteComponent_FullMethodName = "/console.plugin.v1.StoreService/DeleteComponent"
	StoreService_RecordCheck_FullMethodName     = "/console.plugin.v1.StoreService/RecordCheck"
	StoreService_LatestCheck_FullMethodName     = "/console.plugin.v1.StoreService/LatestCheck"
	StoreService_LatestChecks_FullMethodName    = "/console.plugin.v1.StoreService/LatestChecks"
	StoreService_Ping_FullMethodName            = "/console.plugin.v1.StoreService/Ping"
)

Variables

var File_proto_llm_proto protoreflect.FileDescriptor
var File_proto_notify_proto protoreflect.FileDescriptor
var File_proto_status_proto protoreflect.FileDescriptor
var File_proto_store_proto protoreflect.FileDescriptor
var LLMService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "console.plugin.v1.LLMService",
	HandlerType: (*LLMServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Name",
			Handler:    _LLMService_Name_Handler,
		},
		{
			MethodName: "Complete",
			Handler:    _LLMService_Complete_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/llm.proto",
}

LLMService_ServiceDesc is the grpc.ServiceDesc for LLMService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var NotifierService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "console.plugin.v1.NotifierService",
	HandlerType: (*NotifierServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Name",
			Handler:    _NotifierService_Name_Handler,
		},
		{
			MethodName: "Notify",
			Handler:    _NotifierService_Notify_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/notify.proto",
}

NotifierService_ServiceDesc is the grpc.ServiceDesc for NotifierService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var StatusProviderService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "console.plugin.v1.StatusProviderService",
	HandlerType: (*StatusProviderServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Name",
			Handler:    _StatusProviderService_Name_Handler,
		},
		{
			MethodName: "Check",
			Handler:    _StatusProviderService_Check_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/status.proto",
}

StatusProviderService_ServiceDesc is the grpc.ServiceDesc for StatusProviderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var StoreService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "console.plugin.v1.StoreService",
	HandlerType: (*StoreServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateFlag",
			Handler:    _StoreService_CreateFlag_Handler,
		},
		{
			MethodName: "GetFlag",
			Handler:    _StoreService_GetFlag_Handler,
		},
		{
			MethodName: "ListFlags",
			Handler:    _StoreService_ListFlags_Handler,
		},
		{
			MethodName: "UpdateFlag",
			Handler:    _StoreService_UpdateFlag_Handler,
		},
		{
			MethodName: "DeleteFlag",
			Handler:    _StoreService_DeleteFlag_Handler,
		},
		{
			MethodName: "CreateComponent",
			Handler:    _StoreService_CreateComponent_Handler,
		},
		{
			MethodName: "GetComponent",
			Handler:    _StoreService_GetComponent_Handler,
		},
		{
			MethodName: "ListComponents",
			Handler:    _StoreService_ListComponents_Handler,
		},
		{
			MethodName: "UpdateComponent",
			Handler:    _StoreService_UpdateComponent_Handler,
		},
		{
			MethodName: "DeleteComponent",
			Handler:    _StoreService_DeleteComponent_Handler,
		},
		{
			MethodName: "RecordCheck",
			Handler:    _StoreService_RecordCheck_Handler,
		},
		{
			MethodName: "LatestCheck",
			Handler:    _StoreService_LatestCheck_Handler,
		},
		{
			MethodName: "LatestChecks",
			Handler:    _StoreService_LatestChecks_Handler,
		},
		{
			MethodName: "Ping",
			Handler:    _StoreService_Ping_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/store.proto",
}

StoreService_ServiceDesc is the grpc.ServiceDesc for StoreService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterLLMServiceServer

func RegisterLLMServiceServer(s grpc.ServiceRegistrar, srv LLMServiceServer)

func RegisterNotifierServiceServer

func RegisterNotifierServiceServer(s grpc.ServiceRegistrar, srv NotifierServiceServer)

func RegisterStatusProviderServiceServer

func RegisterStatusProviderServiceServer(s grpc.ServiceRegistrar, srv StatusProviderServiceServer)

func RegisterStoreServiceServer

func RegisterStoreServiceServer(s grpc.ServiceRegistrar, srv StoreServiceServer)

Types

type Check

type Check struct {
	Component         string `protobuf:"bytes,1,opt,name=component,proto3" json:"component,omitempty"`
	State             int32  `protobuf:"varint,2,opt,name=state,proto3" json:"state,omitempty"`
	Message           string `protobuf:"bytes,3,opt,name=message,proto3" json:"message,omitempty"`
	LatencyNanos      int64  `protobuf:"varint,4,opt,name=latency_nanos,json=latencyNanos,proto3" json:"latency_nanos,omitempty"`
	CheckedAtUnixNano int64  `protobuf:"varint,5,opt,name=checked_at_unix_nano,json=checkedAtUnixNano,proto3" json:"checked_at_unix_nano,omitempty"`
	// contains filtered or unexported fields
}

func (*Check) Descriptor deprecated

func (*Check) Descriptor() ([]byte, []int)

Deprecated: Use Check.ProtoReflect.Descriptor instead.

func (*Check) GetCheckedAtUnixNano

func (x *Check) GetCheckedAtUnixNano() int64

func (*Check) GetComponent

func (x *Check) GetComponent() string

func (*Check) GetLatencyNanos

func (x *Check) GetLatencyNanos() int64

func (*Check) GetMessage

func (x *Check) GetMessage() string

func (*Check) GetState

func (x *Check) GetState() int32

func (*Check) ProtoMessage

func (*Check) ProtoMessage()

func (*Check) ProtoReflect

func (x *Check) ProtoReflect() protoreflect.Message

func (*Check) Reset

func (x *Check) Reset()

func (*Check) String

func (x *Check) String() string

type CheckList

type CheckList struct {
	Checks []*Check `protobuf:"bytes,1,rep,name=checks,proto3" json:"checks,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckList) Descriptor deprecated

func (*CheckList) Descriptor() ([]byte, []int)

Deprecated: Use CheckList.ProtoReflect.Descriptor instead.

func (*CheckList) GetChecks

func (x *CheckList) GetChecks() []*Check

func (*CheckList) ProtoMessage

func (*CheckList) ProtoMessage()

func (*CheckList) ProtoReflect

func (x *CheckList) ProtoReflect() protoreflect.Message

func (*CheckList) Reset

func (x *CheckList) Reset()

func (*CheckList) String

func (x *CheckList) String() string

type CompleteRequest

type CompleteRequest struct {
	System    string        `protobuf:"bytes,1,opt,name=system,proto3" json:"system,omitempty"`
	Messages  []*LLMMessage `protobuf:"bytes,2,rep,name=messages,proto3" json:"messages,omitempty"`
	MaxTokens int32         `protobuf:"varint,3,opt,name=max_tokens,json=maxTokens,proto3" json:"max_tokens,omitempty"`
	Model     string        `protobuf:"bytes,4,opt,name=model,proto3" json:"model,omitempty"`
	// contains filtered or unexported fields
}

func (*CompleteRequest) Descriptor deprecated

func (*CompleteRequest) Descriptor() ([]byte, []int)

Deprecated: Use CompleteRequest.ProtoReflect.Descriptor instead.

func (*CompleteRequest) GetMaxTokens

func (x *CompleteRequest) GetMaxTokens() int32

func (*CompleteRequest) GetMessages

func (x *CompleteRequest) GetMessages() []*LLMMessage

func (*CompleteRequest) GetModel

func (x *CompleteRequest) GetModel() string

func (*CompleteRequest) GetSystem

func (x *CompleteRequest) GetSystem() string

func (*CompleteRequest) ProtoMessage

func (*CompleteRequest) ProtoMessage()

func (*CompleteRequest) ProtoReflect

func (x *CompleteRequest) ProtoReflect() protoreflect.Message

func (*CompleteRequest) Reset

func (x *CompleteRequest) Reset()

func (*CompleteRequest) String

func (x *CompleteRequest) String() string

type CompleteResponse

type CompleteResponse struct {
	Text string `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
	// contains filtered or unexported fields
}

func (*CompleteResponse) Descriptor deprecated

func (*CompleteResponse) Descriptor() ([]byte, []int)

Deprecated: Use CompleteResponse.ProtoReflect.Descriptor instead.

func (*CompleteResponse) GetText

func (x *CompleteResponse) GetText() string

func (*CompleteResponse) ProtoMessage

func (*CompleteResponse) ProtoMessage()

func (*CompleteResponse) ProtoReflect

func (x *CompleteResponse) ProtoReflect() protoreflect.Message

func (*CompleteResponse) Reset

func (x *CompleteResponse) Reset()

func (*CompleteResponse) String

func (x *CompleteResponse) String() string

type Component

type Component struct {
	Key               string            `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Name              string            `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Description       string            `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	Provider          string            `protobuf:"bytes,4,opt,name=provider,proto3" json:"provider,omitempty"`
	Config            map[string]string `` /* 139-byte string literal not displayed */
	CreatedAtUnixNano int64             `protobuf:"varint,6,opt,name=created_at_unix_nano,json=createdAtUnixNano,proto3" json:"created_at_unix_nano,omitempty"`
	UpdatedAtUnixNano int64             `protobuf:"varint,7,opt,name=updated_at_unix_nano,json=updatedAtUnixNano,proto3" json:"updated_at_unix_nano,omitempty"`
	// contains filtered or unexported fields
}

func (*Component) Descriptor deprecated

func (*Component) Descriptor() ([]byte, []int)

Deprecated: Use Component.ProtoReflect.Descriptor instead.

func (*Component) GetConfig

func (x *Component) GetConfig() map[string]string

func (*Component) GetCreatedAtUnixNano

func (x *Component) GetCreatedAtUnixNano() int64

func (*Component) GetDescription

func (x *Component) GetDescription() string

func (*Component) GetKey

func (x *Component) GetKey() string

func (*Component) GetName

func (x *Component) GetName() string

func (*Component) GetProvider

func (x *Component) GetProvider() string

func (*Component) GetUpdatedAtUnixNano

func (x *Component) GetUpdatedAtUnixNano() int64

func (*Component) ProtoMessage

func (*Component) ProtoMessage()

func (*Component) ProtoReflect

func (x *Component) ProtoReflect() protoreflect.Message

func (*Component) Reset

func (x *Component) Reset()

func (*Component) String

func (x *Component) String() string

type ComponentList

type ComponentList struct {
	Components []*Component `protobuf:"bytes,1,rep,name=components,proto3" json:"components,omitempty"`
	// contains filtered or unexported fields
}

func (*ComponentList) Descriptor deprecated

func (*ComponentList) Descriptor() ([]byte, []int)

Deprecated: Use ComponentList.ProtoReflect.Descriptor instead.

func (*ComponentList) GetComponents

func (x *ComponentList) GetComponents() []*Component

func (*ComponentList) ProtoMessage

func (*ComponentList) ProtoMessage()

func (*ComponentList) ProtoReflect

func (x *ComponentList) ProtoReflect() protoreflect.Message

func (*ComponentList) Reset

func (x *ComponentList) Reset()

func (*ComponentList) String

func (x *ComponentList) String() string

type Empty

type Empty struct {
	// contains filtered or unexported fields
}

func (*Empty) Descriptor deprecated

func (*Empty) Descriptor() ([]byte, []int)

Deprecated: Use Empty.ProtoReflect.Descriptor instead.

func (*Empty) ProtoMessage

func (*Empty) ProtoMessage()

func (*Empty) ProtoReflect

func (x *Empty) ProtoReflect() protoreflect.Message

func (*Empty) Reset

func (x *Empty) Reset()

func (*Empty) String

func (x *Empty) String() string

type Event

type Event struct {
	Type       string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	Title      string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
	Message    string `protobuf:"bytes,3,opt,name=message,proto3" json:"message,omitempty"`
	Component  string `protobuf:"bytes,4,opt,name=component,proto3" json:"component,omitempty"`
	Flag       string `protobuf:"bytes,5,opt,name=flag,proto3" json:"flag,omitempty"`
	From       int32  `protobuf:"varint,6,opt,name=from,proto3" json:"from,omitempty"`
	To         int32  `protobuf:"varint,7,opt,name=to,proto3" json:"to,omitempty"`
	AtUnixNano int64  `protobuf:"varint,8,opt,name=at_unix_nano,json=atUnixNano,proto3" json:"at_unix_nano,omitempty"`
	// contains filtered or unexported fields
}

Event mirrors core.Event.

func (*Event) Descriptor deprecated

func (*Event) Descriptor() ([]byte, []int)

Deprecated: Use Event.ProtoReflect.Descriptor instead.

func (*Event) GetAtUnixNano

func (x *Event) GetAtUnixNano() int64

func (*Event) GetComponent

func (x *Event) GetComponent() string

func (*Event) GetFlag

func (x *Event) GetFlag() string

func (*Event) GetFrom

func (x *Event) GetFrom() int32

func (*Event) GetMessage

func (x *Event) GetMessage() string

func (*Event) GetTitle

func (x *Event) GetTitle() string

func (*Event) GetTo

func (x *Event) GetTo() int32

func (*Event) GetType

func (x *Event) GetType() string

func (*Event) ProtoMessage

func (*Event) ProtoMessage()

func (*Event) ProtoReflect

func (x *Event) ProtoReflect() protoreflect.Message

func (*Event) Reset

func (x *Event) Reset()

func (*Event) String

func (x *Event) String() string

type Flag

type Flag struct {
	Key               string     `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Description       string     `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	Enabled           bool       `protobuf:"varint,3,opt,name=enabled,proto3" json:"enabled,omitempty"`
	Scope             string     `protobuf:"bytes,4,opt,name=scope,proto3" json:"scope,omitempty"`
	Rollout           int32      `protobuf:"varint,5,opt,name=rollout,proto3" json:"rollout,omitempty"`
	Variants          []*Variant `protobuf:"bytes,6,rep,name=variants,proto3" json:"variants,omitempty"`
	Cohort            string     `protobuf:"bytes,7,opt,name=cohort,proto3" json:"cohort,omitempty"`
	Experiment        string     `protobuf:"bytes,8,opt,name=experiment,proto3" json:"experiment,omitempty"`
	CreatedAtUnixNano int64      `protobuf:"varint,9,opt,name=created_at_unix_nano,json=createdAtUnixNano,proto3" json:"created_at_unix_nano,omitempty"`
	UpdatedAtUnixNano int64      `protobuf:"varint,10,opt,name=updated_at_unix_nano,json=updatedAtUnixNano,proto3" json:"updated_at_unix_nano,omitempty"`
	// contains filtered or unexported fields
}

func (*Flag) Descriptor deprecated

func (*Flag) Descriptor() ([]byte, []int)

Deprecated: Use Flag.ProtoReflect.Descriptor instead.

func (*Flag) GetCohort

func (x *Flag) GetCohort() string

func (*Flag) GetCreatedAtUnixNano

func (x *Flag) GetCreatedAtUnixNano() int64

func (*Flag) GetDescription

func (x *Flag) GetDescription() string

func (*Flag) GetEnabled

func (x *Flag) GetEnabled() bool

func (*Flag) GetExperiment

func (x *Flag) GetExperiment() string

func (*Flag) GetKey

func (x *Flag) GetKey() string

func (*Flag) GetRollout

func (x *Flag) GetRollout() int32

func (*Flag) GetScope

func (x *Flag) GetScope() string

func (*Flag) GetUpdatedAtUnixNano

func (x *Flag) GetUpdatedAtUnixNano() int64

func (*Flag) GetVariants

func (x *Flag) GetVariants() []*Variant

func (*Flag) ProtoMessage

func (*Flag) ProtoMessage()

func (*Flag) ProtoReflect

func (x *Flag) ProtoReflect() protoreflect.Message

func (*Flag) Reset

func (x *Flag) Reset()

func (*Flag) String

func (x *Flag) String() string

type FlagList

type FlagList struct {
	Flags []*Flag `protobuf:"bytes,1,rep,name=flags,proto3" json:"flags,omitempty"`
	// contains filtered or unexported fields
}

func (*FlagList) Descriptor deprecated

func (*FlagList) Descriptor() ([]byte, []int)

Deprecated: Use FlagList.ProtoReflect.Descriptor instead.

func (*FlagList) GetFlags

func (x *FlagList) GetFlags() []*Flag

func (*FlagList) ProtoMessage

func (*FlagList) ProtoMessage()

func (*FlagList) ProtoReflect

func (x *FlagList) ProtoReflect() protoreflect.Message

func (*FlagList) Reset

func (x *FlagList) Reset()

func (*FlagList) String

func (x *FlagList) String() string

type Key

type Key struct {
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*Key) Descriptor deprecated

func (*Key) Descriptor() ([]byte, []int)

Deprecated: Use Key.ProtoReflect.Descriptor instead.

func (*Key) GetKey

func (x *Key) GetKey() string

func (*Key) ProtoMessage

func (*Key) ProtoMessage()

func (*Key) ProtoReflect

func (x *Key) ProtoReflect() protoreflect.Message

func (*Key) Reset

func (x *Key) Reset()

func (*Key) String

func (x *Key) String() string

type LLMEmpty

type LLMEmpty struct {
	// contains filtered or unexported fields
}

func (*LLMEmpty) Descriptor deprecated

func (*LLMEmpty) Descriptor() ([]byte, []int)

Deprecated: Use LLMEmpty.ProtoReflect.Descriptor instead.

func (*LLMEmpty) ProtoMessage

func (*LLMEmpty) ProtoMessage()

func (*LLMEmpty) ProtoReflect

func (x *LLMEmpty) ProtoReflect() protoreflect.Message

func (*LLMEmpty) Reset

func (x *LLMEmpty) Reset()

func (*LLMEmpty) String

func (x *LLMEmpty) String() string

type LLMMessage

type LLMMessage struct {
	Role string `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"`
	Text string `protobuf:"bytes,2,opt,name=text,proto3" json:"text,omitempty"`
	// contains filtered or unexported fields
}

func (*LLMMessage) Descriptor deprecated

func (*LLMMessage) Descriptor() ([]byte, []int)

Deprecated: Use LLMMessage.ProtoReflect.Descriptor instead.

func (*LLMMessage) GetRole

func (x *LLMMessage) GetRole() string

func (*LLMMessage) GetText

func (x *LLMMessage) GetText() string

func (*LLMMessage) ProtoMessage

func (*LLMMessage) ProtoMessage()

func (*LLMMessage) ProtoReflect

func (x *LLMMessage) ProtoReflect() protoreflect.Message

func (*LLMMessage) Reset

func (x *LLMMessage) Reset()

func (*LLMMessage) String

func (x *LLMMessage) String() string

type LLMName

type LLMName struct {
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*LLMName) Descriptor deprecated

func (*LLMName) Descriptor() ([]byte, []int)

Deprecated: Use LLMName.ProtoReflect.Descriptor instead.

func (*LLMName) GetName

func (x *LLMName) GetName() string

func (*LLMName) ProtoMessage

func (*LLMName) ProtoMessage()

func (*LLMName) ProtoReflect

func (x *LLMName) ProtoReflect() protoreflect.Message

func (*LLMName) Reset

func (x *LLMName) Reset()

func (*LLMName) String

func (x *LLMName) String() string

type LLMServiceClient

type LLMServiceClient interface {
	Name(ctx context.Context, in *LLMEmpty, opts ...grpc.CallOption) (*LLMName, error)
	Complete(ctx context.Context, in *CompleteRequest, opts ...grpc.CallOption) (*CompleteResponse, error)
}

LLMServiceClient is the client API for LLMService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

LLMService is the gRPC contract for a Console LLM-provider plugin. It mirrors the Go llm.Provider interface: a single text completion.

func NewLLMServiceClient

func NewLLMServiceClient(cc grpc.ClientConnInterface) LLMServiceClient

type LLMServiceServer

type LLMServiceServer interface {
	Name(context.Context, *LLMEmpty) (*LLMName, error)
	Complete(context.Context, *CompleteRequest) (*CompleteResponse, error)
	// contains filtered or unexported methods
}

LLMServiceServer is the server API for LLMService service. All implementations must embed UnimplementedLLMServiceServer for forward compatibility.

LLMService is the gRPC contract for a Console LLM-provider plugin. It mirrors the Go llm.Provider interface: a single text completion.

type NotifierName

type NotifierName struct {
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*NotifierName) Descriptor deprecated

func (*NotifierName) Descriptor() ([]byte, []int)

Deprecated: Use NotifierName.ProtoReflect.Descriptor instead.

func (*NotifierName) GetName

func (x *NotifierName) GetName() string

func (*NotifierName) ProtoMessage

func (*NotifierName) ProtoMessage()

func (*NotifierName) ProtoReflect

func (x *NotifierName) ProtoReflect() protoreflect.Message

func (*NotifierName) Reset

func (x *NotifierName) Reset()

func (*NotifierName) String

func (x *NotifierName) String() string

type NotifierServiceClient

type NotifierServiceClient interface {
	Name(ctx context.Context, in *NotifyEmpty, opts ...grpc.CallOption) (*NotifierName, error)
	Notify(ctx context.Context, in *Event, opts ...grpc.CallOption) (*NotifyEmpty, error)
}

NotifierServiceClient is the client API for NotifierService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

NotifierService is the gRPC contract for a Console notifier plugin. It mirrors the Go notify.Notifier interface: a sink that delivers a domain Event.

type NotifierServiceServer

type NotifierServiceServer interface {
	Name(context.Context, *NotifyEmpty) (*NotifierName, error)
	Notify(context.Context, *Event) (*NotifyEmpty, error)
	// contains filtered or unexported methods
}

NotifierServiceServer is the server API for NotifierService service. All implementations must embed UnimplementedNotifierServiceServer for forward compatibility.

NotifierService is the gRPC contract for a Console notifier plugin. It mirrors the Go notify.Notifier interface: a sink that delivers a domain Event.

type NotifyEmpty

type NotifyEmpty struct {
	// contains filtered or unexported fields
}

func (*NotifyEmpty) Descriptor deprecated

func (*NotifyEmpty) Descriptor() ([]byte, []int)

Deprecated: Use NotifyEmpty.ProtoReflect.Descriptor instead.

func (*NotifyEmpty) ProtoMessage

func (*NotifyEmpty) ProtoMessage()

func (*NotifyEmpty) ProtoReflect

func (x *NotifyEmpty) ProtoReflect() protoreflect.Message

func (*NotifyEmpty) Reset

func (x *NotifyEmpty) Reset()

func (*NotifyEmpty) String

func (x *NotifyEmpty) String() string

type StatusCheck

type StatusCheck struct {
	Component         string `protobuf:"bytes,1,opt,name=component,proto3" json:"component,omitempty"`
	State             int32  `protobuf:"varint,2,opt,name=state,proto3" json:"state,omitempty"`
	Message           string `protobuf:"bytes,3,opt,name=message,proto3" json:"message,omitempty"`
	LatencyNanos      int64  `protobuf:"varint,4,opt,name=latency_nanos,json=latencyNanos,proto3" json:"latency_nanos,omitempty"`
	CheckedAtUnixNano int64  `protobuf:"varint,5,opt,name=checked_at_unix_nano,json=checkedAtUnixNano,proto3" json:"checked_at_unix_nano,omitempty"`
	// contains filtered or unexported fields
}

StatusCheck mirrors core.Check. Provider errors are carried in state/message, not as a gRPC error, matching the in-process contract.

func (*StatusCheck) Descriptor deprecated

func (*StatusCheck) Descriptor() ([]byte, []int)

Deprecated: Use StatusCheck.ProtoReflect.Descriptor instead.

func (*StatusCheck) GetCheckedAtUnixNano

func (x *StatusCheck) GetCheckedAtUnixNano() int64

func (*StatusCheck) GetComponent

func (x *StatusCheck) GetComponent() string

func (*StatusCheck) GetLatencyNanos

func (x *StatusCheck) GetLatencyNanos() int64

func (*StatusCheck) GetMessage

func (x *StatusCheck) GetMessage() string

func (*StatusCheck) GetState

func (x *StatusCheck) GetState() int32

func (*StatusCheck) ProtoMessage

func (*StatusCheck) ProtoMessage()

func (*StatusCheck) ProtoReflect

func (x *StatusCheck) ProtoReflect() protoreflect.Message

func (*StatusCheck) Reset

func (x *StatusCheck) Reset()

func (*StatusCheck) String

func (x *StatusCheck) String() string

type StatusComponent

type StatusComponent struct {
	Key         string            `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Name        string            `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Description string            `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	Provider    string            `protobuf:"bytes,4,opt,name=provider,proto3" json:"provider,omitempty"`
	Config      map[string]string `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

StatusComponent mirrors the fields of core.Component a provider reads.

func (*StatusComponent) Descriptor deprecated

func (*StatusComponent) Descriptor() ([]byte, []int)

Deprecated: Use StatusComponent.ProtoReflect.Descriptor instead.

func (*StatusComponent) GetConfig

func (x *StatusComponent) GetConfig() map[string]string

func (*StatusComponent) GetDescription

func (x *StatusComponent) GetDescription() string

func (*StatusComponent) GetKey

func (x *StatusComponent) GetKey() string

func (*StatusComponent) GetName

func (x *StatusComponent) GetName() string

func (*StatusComponent) GetProvider

func (x *StatusComponent) GetProvider() string

func (*StatusComponent) ProtoMessage

func (*StatusComponent) ProtoMessage()

func (*StatusComponent) ProtoReflect

func (x *StatusComponent) ProtoReflect() protoreflect.Message

func (*StatusComponent) Reset

func (x *StatusComponent) Reset()

func (*StatusComponent) String

func (x *StatusComponent) String() string

type StatusEmpty

type StatusEmpty struct {
	// contains filtered or unexported fields
}

func (*StatusEmpty) Descriptor deprecated

func (*StatusEmpty) Descriptor() ([]byte, []int)

Deprecated: Use StatusEmpty.ProtoReflect.Descriptor instead.

func (*StatusEmpty) ProtoMessage

func (*StatusEmpty) ProtoMessage()

func (*StatusEmpty) ProtoReflect

func (x *StatusEmpty) ProtoReflect() protoreflect.Message

func (*StatusEmpty) Reset

func (x *StatusEmpty) Reset()

func (*StatusEmpty) String

func (x *StatusEmpty) String() string

type StatusName

type StatusName struct {
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*StatusName) Descriptor deprecated

func (*StatusName) Descriptor() ([]byte, []int)

Deprecated: Use StatusName.ProtoReflect.Descriptor instead.

func (*StatusName) GetName

func (x *StatusName) GetName() string

func (*StatusName) ProtoMessage

func (*StatusName) ProtoMessage()

func (*StatusName) ProtoReflect

func (x *StatusName) ProtoReflect() protoreflect.Message

func (*StatusName) Reset

func (x *StatusName) Reset()

func (*StatusName) String

func (x *StatusName) String() string

type StatusProviderServiceClient

type StatusProviderServiceClient interface {
	Name(ctx context.Context, in *StatusEmpty, opts ...grpc.CallOption) (*StatusName, error)
	Check(ctx context.Context, in *StatusComponent, opts ...grpc.CallOption) (*StatusCheck, error)
}

StatusProviderServiceClient is the client API for StatusProviderService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

StatusProviderService is the gRPC contract for a Console status-provider plugin. It mirrors the Go status.Provider interface: a named health check.

type StatusProviderServiceServer

type StatusProviderServiceServer interface {
	Name(context.Context, *StatusEmpty) (*StatusName, error)
	Check(context.Context, *StatusComponent) (*StatusCheck, error)
	// contains filtered or unexported methods
}

StatusProviderServiceServer is the server API for StatusProviderService service. All implementations must embed UnimplementedStatusProviderServiceServer for forward compatibility.

StatusProviderService is the gRPC contract for a Console status-provider plugin. It mirrors the Go status.Provider interface: a named health check.

type StoreServiceClient

type StoreServiceClient interface {
	CreateFlag(ctx context.Context, in *Flag, opts ...grpc.CallOption) (*Empty, error)
	GetFlag(ctx context.Context, in *Key, opts ...grpc.CallOption) (*Flag, error)
	ListFlags(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*FlagList, error)
	UpdateFlag(ctx context.Context, in *Flag, opts ...grpc.CallOption) (*Empty, error)
	DeleteFlag(ctx context.Context, in *Key, opts ...grpc.CallOption) (*Empty, error)
	CreateComponent(ctx context.Context, in *Component, opts ...grpc.CallOption) (*Empty, error)
	GetComponent(ctx context.Context, in *Key, opts ...grpc.CallOption) (*Component, error)
	ListComponents(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*ComponentList, error)
	UpdateComponent(ctx context.Context, in *Component, opts ...grpc.CallOption) (*Empty, error)
	DeleteComponent(ctx context.Context, in *Key, opts ...grpc.CallOption) (*Empty, error)
	RecordCheck(ctx context.Context, in *Check, opts ...grpc.CallOption) (*Empty, error)
	LatestCheck(ctx context.Context, in *Key, opts ...grpc.CallOption) (*Check, error)
	LatestChecks(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*CheckList, error)
	Ping(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*Empty, error)
}

StoreServiceClient is the client API for StoreService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

StoreService is the gRPC contract for a Console storage-backend plugin. It mirrors the Go store.Store interface. Not-found and conflict conditions are conveyed via gRPC status codes (NotFound, AlreadyExists) and mapped back to core.ErrNotFound / core.ErrConflict on the host side.

type StoreServiceServer

type StoreServiceServer interface {
	CreateFlag(context.Context, *Flag) (*Empty, error)
	GetFlag(context.Context, *Key) (*Flag, error)
	ListFlags(context.Context, *Empty) (*FlagList, error)
	UpdateFlag(context.Context, *Flag) (*Empty, error)
	DeleteFlag(context.Context, *Key) (*Empty, error)
	CreateComponent(context.Context, *Component) (*Empty, error)
	GetComponent(context.Context, *Key) (*Component, error)
	ListComponents(context.Context, *Empty) (*ComponentList, error)
	UpdateComponent(context.Context, *Component) (*Empty, error)
	DeleteComponent(context.Context, *Key) (*Empty, error)
	RecordCheck(context.Context, *Check) (*Empty, error)
	LatestCheck(context.Context, *Key) (*Check, error)
	LatestChecks(context.Context, *Empty) (*CheckList, error)
	Ping(context.Context, *Empty) (*Empty, error)
	// contains filtered or unexported methods
}

StoreServiceServer is the server API for StoreService service. All implementations must embed UnimplementedStoreServiceServer for forward compatibility.

StoreService is the gRPC contract for a Console storage-backend plugin. It mirrors the Go store.Store interface. Not-found and conflict conditions are conveyed via gRPC status codes (NotFound, AlreadyExists) and mapped back to core.ErrNotFound / core.ErrConflict on the host side.

type UnimplementedLLMServiceServer

type UnimplementedLLMServiceServer struct{}

UnimplementedLLMServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedLLMServiceServer) Complete

func (UnimplementedLLMServiceServer) Name

type UnimplementedNotifierServiceServer

type UnimplementedNotifierServiceServer struct{}

UnimplementedNotifierServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedNotifierServiceServer) Name

func (UnimplementedNotifierServiceServer) Notify

type UnimplementedStatusProviderServiceServer

type UnimplementedStatusProviderServiceServer struct{}

UnimplementedStatusProviderServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedStatusProviderServiceServer) Check

func (UnimplementedStatusProviderServiceServer) Name

type UnimplementedStoreServiceServer

type UnimplementedStoreServiceServer struct{}

UnimplementedStoreServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedStoreServiceServer) CreateComponent

func (UnimplementedStoreServiceServer) CreateFlag

func (UnimplementedStoreServiceServer) DeleteComponent

func (UnimplementedStoreServiceServer) DeleteFlag

func (UnimplementedStoreServiceServer) GetComponent

func (UnimplementedStoreServiceServer) GetFlag

func (UnimplementedStoreServiceServer) LatestCheck

func (UnimplementedStoreServiceServer) LatestChecks

func (UnimplementedStoreServiceServer) ListComponents

func (UnimplementedStoreServiceServer) ListFlags

func (UnimplementedStoreServiceServer) Ping

func (UnimplementedStoreServiceServer) RecordCheck

func (UnimplementedStoreServiceServer) UpdateComponent

func (UnimplementedStoreServiceServer) UpdateFlag

type UnsafeLLMServiceServer

type UnsafeLLMServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLLMServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LLMServiceServer will result in compilation errors.

type UnsafeNotifierServiceServer

type UnsafeNotifierServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeNotifierServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NotifierServiceServer will result in compilation errors.

type UnsafeStatusProviderServiceServer

type UnsafeStatusProviderServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeStatusProviderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StatusProviderServiceServer will result in compilation errors.

type UnsafeStoreServiceServer

type UnsafeStoreServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeStoreServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StoreServiceServer will result in compilation errors.

type Variant

type Variant struct {
	Key    string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Value  string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	Weight int32  `protobuf:"varint,3,opt,name=weight,proto3" json:"weight,omitempty"`
	// contains filtered or unexported fields
}

func (*Variant) Descriptor deprecated

func (*Variant) Descriptor() ([]byte, []int)

Deprecated: Use Variant.ProtoReflect.Descriptor instead.

func (*Variant) GetKey

func (x *Variant) GetKey() string

func (*Variant) GetValue

func (x *Variant) GetValue() string

func (*Variant) GetWeight

func (x *Variant) GetWeight() int32

func (*Variant) ProtoMessage

func (*Variant) ProtoMessage()

func (*Variant) ProtoReflect

func (x *Variant) ProtoReflect() protoreflect.Message

func (*Variant) Reset

func (x *Variant) Reset()

func (*Variant) String

func (x *Variant) String() string

Jump to